@@ -13,6 +13,7 @@
       if you know the corresponding password
     * getting a user's full public tagging vocabulary, i.e. tags and tag counts
     * HTTP proxy support
+    * updated to support delicious.com "version 2" (mini-relaunch as of August 2008)
 
     The official delicious.com API and the JSON/RSS feeds do not provide all
     the functionality mentioned above, and in such cases this module will query
@@ -45,7 +46,7 @@ __license__ = "GPLv2"
 __maintainer__ = "Michael G. Noll"
 __status__ = "Development"
 __url__ = "http://www.michael-noll.com/"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 
 import base64
 import cgi
@@ -90,9 +91,9 @@ class DeliciousUser(object):
             a user's bookmark collection.
 
             url is a 'unicode'
-            tags is a 'list' of 'unicode'
+            tags is a 'list' of 'unicode' ([] if no tags)
             title is a 'unicode'
-            comment is a 'unicode'
+            comment is a 'unicode' (u"" if no comment)
             timestamp is a 'datetime.datetime'
 
         tags (read-only property):
@@ -152,7 +153,7 @@ class DeliciousURL(object):
 
             user is a 'unicode'
             tags is a 'list' of 'unicode's ([] if no tags)
-            comment is a 'list' of 'unicode's (None if no comment)
+            comment is a 'unicode' (u"" if no comment)
             timestamp is a 'datetime.datetime' (granularity: creation *day*,
                 i.e. the day but not the time of day)
 
@@ -548,7 +549,7 @@ class DeliciousAPI(object):
                     timestamp =  datetime.datetime.strptime(date_str, '%d %b %y')
 
             # extract comments
-            comment = None
+            comment = u""
             datas = bookmark_element.findAll("div", attrs={"class": "data"})
             if datas:
                 divs = datas[0].findAll("div", attrs={"class": "description"})
@@ -601,7 +602,7 @@ class DeliciousAPI(object):
                         timestamp =  datetime.datetime.strptime(date_str, '%d %b %y')
 
                 # extract comments
-                comment = None
+                comment = u""
                 datas = bookmark_element.findAll("div", attrs={"class": "data"})
                 if datas:
                     links = datas[0].findAll("a", attrs={"class": "taggedlink"})
@@ -678,7 +679,7 @@ class DeliciousAPI(object):
                     url = element["href"]
                     title = element["description"] or u""
                     comment = element["extended"] or u""
-                    tags = None
+                    tags = []
                     if element["tag"]:
                         tags = element["tag"].split()
                     timestamp = datetime.datetime.strptime(element["time"], "%Y-%m-%dT%H:%M:%SZ")
@@ -700,7 +701,7 @@ class DeliciousAPI(object):
                         pass
 
                     url = timestamp = None
-                    title = comment = ""
+                    title = comment = u""
                     tags = []
 
                     for post in posts:
